@@ -31,27 +31,28 @@ sub main {
 	my $root = POE::Component::Curses->spawn();
 
 
-	$root->add_window(
-		my $window2 = Curses::Toolkit::Widget::Window->new()
-		  ->set_name('window2')
-		  ->set_title("a title2")
-	);
+	$root->add_window( my $window2 =
+			Curses::Toolkit::Widget::Window->new()->set_name('window2')->set_title("a title2") );
 
 	my $button3 = Curses::Toolkit::Widget::Button->new_with_label('This is a button 3');
 	my $button4 = Curses::Toolkit::Widget::Button->new_with_label('This is a button 4');
 	$window2->add_widget(
-		my $vbox = Curses::Toolkit::Widget::VBox->new()
-		  ->pack_end($button3, { expand => 0 })
-#		  ->pack_end($button4, { expand => 0 })
+		my $vbox =
+			Curses::Toolkit::Widget::VBox->new()->pack_end( $button3, { expand => 0 } )
+
+			#		  ->pack_end($button4, { expand => 0 })
+	);
+	$window2->set_coordinates(
+		x1 => '15%', y1 => '15%',
+		x2 => '85%',
+		y2 => '85%',
 	);
-	$window2->set_coordinates(x1 => '15%',   y1 => '15%',
-							 x2 => '85%',
-							 y2 => '85%',
-							);
 	$button3->set_focus(1);
-	$button3->signal_connect(clicked => sub {
-								 print STDERR "clicked button 3\n";
-							 });
+	$button3->signal_connect(
+		clicked => sub {
+			print STDERR "clicked button 3\n";
+		}
+	);
 
 	POE::Kernel->run();
 }
\ No newline at end of file
